@@ -20,10 +20,16 @@
 #define SEVENZIP_H
 
 #include <gtk/gtk.h>
-#include "callbacks.h"
-#include "interface.h"
-#include "archive.h"
+#include <stdlib.h>
 #include "string_utils.h"
+#include "support.h"
+#include "archive.h"
 
-void Open7Zip ( XArchive *archive );
+gboolean jump_header, last_line;
+void xa_7zip_delete (XArchive *,GSList *);
+void xa_7zip_add (XArchive *,GString *,gchar *);
+gboolean xa_7zip_extract(XArchive *,GSList *);
+void xa_7zip_test (XArchive *);
+void xa_open_7zip (XArchive *);
+void xa_get_7zip_line_content (gchar *, gpointer );
 #endif
