@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2006 Giuseppe Torelli - <colossus73@gmail.com>
+ *  Copyright (C) 2008 Giuseppe Torelli - <colossus73@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,11 +20,17 @@
 #define ARJ_H
 
 #include <gtk/gtk.h>
-#include "callbacks.h"
-#include "interface.h"
-#include "main.h"
+#include <string.h>
+#include <stdlib.h>
+#include "string_utils.h"
+#include "support.h"
 #include "archive.h"
-
-void OpenArj ( XArchive *archive );
-gboolean no_attr;
+gboolean jump_header, encrypted, last_line;
+unsigned short int arj_line;
+void xa_arj_delete (XArchive *,GSList *);
+void xa_arj_add (XArchive *,GString *,gchar *);
+gboolean xa_arj_extract(XArchive *,GSList *);
+void xa_arj_test (XArchive *);
+void xa_get_arj_line_content (gchar *line, gpointer data);
+void xa_open_arj (XArchive *archive);
 #endif
