@@ -1,7 +1,5 @@
 /*
- *  Xarchiver
- *
- *  Copyright (C) 2005 Giuseppe Torelli - Colossus
+ *  Copyright (C) 2008 Giuseppe Torelli <colossus73@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,24 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  */
- 
+
 #ifndef BZIP2_H
 #define BZIP2_H
 
- #include "config.h"
- #include <gtk/gtk.h>
- #include "callbacks.h"
- #include "interface.h"
- #include "support.h"
- #include "main.h"
+#include <gtk/gtk.h>
+#include "support.h"
+#include "main.h"
+#include "archive.h"
 
-void OpenBzip2 ( gboolean mode , gchar *path );
-void Bzip2Extract ( gboolean flag );
-gboolean Bzip2Output (GIOChannel *ioc, GIOCondition cond, gpointer data);
-gboolean ExtractToDifferentLocation (GIOChannel *ioc, GIOCondition cond , gpointer data);
-void RecompressArchive ( gint status );
-void DecompressBzipGzip ( GString *list , gchar *path , gboolean dummy , gboolean add);
-GChildWatchFunc *AddToTar (GPid pid,gint status , gpointer data);
-void Bzip2Add ( gchar *filename , gboolean flag );
-gchar *OpenTempFile ( gboolean dummy , gchar *temp_path );
+void xa_open_bzip2_lzma (XArchive *);
+gboolean lzma_bzip2_extract (XArchive *,GSList*);
+void xa_open_tar_compressed_file(XArchive *);
 #endif
