@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2005 Giuseppe Torelli - <colossus73@gmail.com>
+ *  Copyright (C) 2008 Giuseppe Torelli - <colossus73@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,12 +20,16 @@
 #define RAR_H
 
 #include <gtk/gtk.h>
-#include "interface.h"
-#include "callbacks.h"
-#include "main.h"
-#include "archive.h"
+#include <string.h>
+#include <stdlib.h>
 #include "string_utils.h"
-
-gboolean jump_header , odd_line;
-void OpenRar ( XArchive *archive );
+#include "support.h"
+#include "archive.h"
+gboolean jump_header,jump_comment,read_filename, last_line, encrypted;
+void xa_rar_delete (XArchive *,GSList *);
+void xa_rar_add (XArchive *,GString *,gchar *);
+gboolean xa_rar_extract(XArchive *,GSList *);
+void xa_rar_test (XArchive *);
+void xa_get_rar_line_content (gchar *line, gpointer data);
+void xa_open_rar ( XArchive *archive );
 #endif
